@@ -16,7 +16,7 @@ Instructions::Instructions(QWidget *parent) :
     ui->labelMain->setText(tr( "<b>Fresh Swap</b><br>\
                                Moves Swap to a fresh SD location<br>\
                                <b>Swap to Device</b><br>\
-                               Moves Swap to Device<br>\
+                               To allow back cover removal<br>\
                                <b>Show Current</b><br>\
                                Shows current swap location(s)<br>\
                                <b>Check Usage</b><br>\
